#
# spec file for package sqlcipher
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         lib_name lib%{name}-3_11_0-0
Name:           sqlcipher
Version:        3.4.0
Release:        2.5
Summary:        SQLite database encryption
License:        BSD-3-Clause
Group:          Productivity/Databases/Clients
Url:            http://sqlcipher.net
Source:         https://github.com/sqlcipher/sqlcipher/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  readline-devel
BuildRequires:  sqlite3-devel
BuildRequires:  tcl-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SQLCipher is an SQLite extension that provides transparent 256-bit AES
encryption of database files. Pages are encrypted before being written to
disk and are decrypted when read back. Due to the small footprint and great
performance it’s ideal for protecting embedded application databases and is
well suited for mobile development.

%package -n %{lib_name}
Summary:        Shared library for SQLCipher
Group:          System/Libraries

%description -n %{lib_name}
SQLCipher is an SQLite extension that provides transparent 256-bit AES
encryption of database files. Pages are encrypted before being written to
disk and are decrypted when read back. Due to the small footprint and great
performance it’s ideal for protecting embedded application databases and is
well suited for mobile development/

This package contains shared library.

%package tcl
Summary:        Tcl extension for sqlcipher
Group:          Development/Languages/Tcl

%description tcl
SQLCipher is an SQLite extension that provides transparent 256-bit AES
encryption of database files. Pages are encrypted before being written to
disk and are decrypted when read back. Due to the small footprint and great
performance it’s ideal for protecting embedded application databases and is
well suited for mobile development/

This package provides tcl extension for SQLCipher.

%package devel
Summary:        Development files for SQLCipher
Group:          Development/Libraries/C and C++
Requires:       %{lib_name} = %{version}-%{release}
Requires:       %{name}     = %{version}-%{release}
Requires:       %{name}-tcl = %{version}-%{release}

%description devel
SQLCipher is an SQLite extension that provides transparent 256-bit AES
encryption of database files. Pages are encrypted before being written to
disk and are decrypted when read back. Due to the small footprint and great
performance it’s ideal for protecting embedded application databases and is
well suited for mobile development.

This package contains development files for SQLCipher.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -DSQLITE_HAS_CODEC -DSQLITE_TEMP_STORE=2"
export LDFLAGS="-lcrypto"
%configure \
  --enable-threadsafe \
  --enable-cross-thread-connections \
  --enable-releasemode \
  --disable-static \
  --with-crypto-lib \
  --with-tcl=%{_libdir} \
  --enable-tempstore=yes
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README.md LICENSE
%{_bindir}/sqlcipher

%files -n %{lib_name}
%defattr(-,root,root)
%doc README.md LICENSE
%{_libdir}/libsqlcipher-3.11.0.so.0
%{_libdir}/libsqlcipher-3.11.0.so.0.8.6

%files tcl
%defattr(-,root,root)
%doc README.md LICENSE
%dir %{_libdir}/tcl/tcl8.?/sqlite3
%{_libdir}/tcl/tcl8.?/sqlite3/libtclsqlite3.so
%{_libdir}/tcl/tcl8.?/sqlite3/pkgIndex.tcl

%files devel
%defattr(-,root,root)
%doc README.md LICENSE
%{_libdir}/libsqlcipher.so
%{_libdir}/pkgconfig/sqlcipher.pc
%{_includedir}/sqlcipher/
%{_includedir}/sqlcipher/sqlite3.h
%{_includedir}/sqlcipher/sqlite3ext.h

%changelog
* Mon Apr 18 2016 mpluskal@suse.com
- Use pretty name for tarball
* Sun Apr 17 2016 ecsos@opensuse.org
- update to 3.4.0
  - Added `PRAGMA cipher_provider_version`
  - Merged upstream SQLite 3.11.0
  - Deprecated `PRAGMA cipher` command
* Thu Feb  4 2016 mpluskal@suse.com
- Use optflags
- Fix building of tcl support on SLE11
* Sun Dec 20 2015 mpluskal@suse.com
- Cleanup spec file
* Sat Jul 18 2015 goedhart.martijn@gmail.com
- Update to c01b94f (2015-07-13)
* Mon Oct 27 2014 goedhart.martijn@gmail.com
- Update to e7b8d1f (2014-09-30)
* Tue Jun 24 2014 goedhart.martijn@gmail.com
- Update to 9096584 (2014-04-23)
* Wed Dec 18 2013 goedhart.martijn@gmail.com
- Update to 8d0acdb (2013-12-06)
* Wed Dec 18 2013 goedhart.martijn@gmail.com
- Update to 8d0acdb (2013-12-06)
* Wed Dec 18 2013 goedhart.martijn@gmail.com
- Update to 8d0acdb (2013-12-06)
